@@ -6,7 +6,7 @@ use base qw( Clustericious::Command );
 use Mojolicious::Command::daemon;
 
 # ABSTRACT: Clustericious command to stat nginx
-our $VERSION = '1.21'; # VERSION
+our $VERSION = '1.22'; # VERSION
 
 
 sub description { Mojolicious::Command::daemon->new->description };
@@ -16,11 +16,14 @@ sub run
 {
   my($self, @args) = @_;
   
-  if(my $url = $self->app->config->{url})
+  if(!grep /^-l/, @args)
   {
-    unshift @args, -l => $url;
+    if(my $url = $self->app->config->{url})
+    {
+      unshift @args, -l => $url;
+    }
   }
-  
+
   Mojolicious::Command::daemon::run($self, @args);
 }
 
@@ -38,7 +41,7 @@ Clustericious::Command::daemon - Clustericious command to stat nginx
 
 =head1 VERSION
 
-version 1.21
+version 1.22
 
 =head1 DESCRIPTION
 
